#
# spec file for package ngspice
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without oldapps

%global flavor %{nil}

%if "%flavor" == "shlibs"
%define build_shared 1
%endif
%define pname   ngspice

Name:           %pname%{?build_shared:-shared}
%define so_ver 0
Version:        30
Release:        bp156.3.6
Summary:        Mixed-level, Mixed-signal Circuit Simulator Based on spice3f5
License:        BSD-2-Clause
Group:          Productivity/Scientific/Electronics
Url:            http://ngspice.sourceforge.net
Source0:        http://downloads.sourceforge.net/%{pname}/%{pname}-%{version}.tar.gz
Source1:        http://downloads.sourceforge.net/%{pname}/%{pname}-%{version}-manual.pdf
Patch1:         ngspice-Use-gnuplot-terminal-auto-detection.patch
BuildRequires:  bison
BuildRequires:  fftw3-devel
BuildRequires:  flex
BuildRequires:  gcc-fortran
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
BuildRequires:  xorg-x11-devel
Requires:       %{pname}-scripts = %{version}
Requires:       %{pname}-xspice-cm = %{version}
Requires:       lib%{pname}%{so_ver} = %{version}
Recommends:     %{pname}-doc = %{version}
Provides:       ng-spice-rework = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice.

%package doc
Summary:        Documentation for ngspice
Group:          Documentation/Other
Requires:       %{pname} = %{version}

%description doc
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice.

%package xspice-cm
Summary:        Xspice code model Plugins
Group:          Productivity/Scientific/Electronics

%description xspice-cm
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the Xspice code model plugins.

%package scripts
Summary:        Ngspice init scripts
Group:          Productivity/Scientific/Electronics

%description scripts
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the ngspice init scripts shared
between ngspice and libngspice.


%package xspice-cm-devel
Summary:        Development files for Xspice code model plugins
Group:          Development/Libraries/Other
Requires:       %{pname}-xspice-cm = %{version}

%description xspice-cm-devel
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the development files for Xspice
code model plugins.

%package -n lib%{pname}%{so_ver}
Summary:        Shared libraries for ngspice
Group:          System/Libraries
Requires:       %{pname}-scripts
Requires:       %{pname}-xspice-cm

%description -n lib%{pname}%{so_ver}
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the shared libraries.

%package -n lib%{pname}-devel
Summary:        Development files for ngspice
Group:          Development/Libraries/Other
Requires:       lib%{pname}%{so_ver} = %{version}

%description -n lib%{pname}-devel
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the development files.

%prep
%setup -q -n ngspice-%{version}
cp %{S:1} .
%patch1 -p1

%build
export CFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
%configure \
    --disable-debug \
%if 0%{!?build_shared:1}
    --with-x \
%else
    --with-ngshared \
%endif
    %{?with_oldapps:--enable-oldapps} \
    --with-readline=yes \
    --enable-xspice \
    --enable-cider \
    --enable-openmp

make V=1 %{?_smp_mflags}

%install
%makeinstall
find %{buildroot} -type f -name "*.la" -delete -print
%if 0%{!?build_shared:1}
rm %{buildroot}%{_includedir}/%{pname}/sharedspice.h
%else
rm -rf %{buildroot}%{_bindir}/cmpp %{buildroot}/%{_mandir} \
       %{buildroot}%{_libdir}/%{pname} \
       %{buildroot}%{_datadir}/%{pname}/dlmain.c \
       %{buildroot}%{_datadir}/%{pname}/scripts \
       %{buildroot}%{_includedir}/%{pname}/[^s]*.h \
       %{buildroot}%{_includedir}/%{pname}/s[^h]*.h
%endif

%post -n lib%{pname}%{so_ver} -p /sbin/ldconfig
%postun -n lib%{pname}%{so_ver} -p /sbin/ldconfig

%if 0%{!?build_shared:1}
%files
%license COPYING
%doc ANALYSES AUTHORS BUGS DEVICES FAQ NEWS README
%{_bindir}/ngspice
%{_mandir}/man1/ngspice.1%{?ext_man}
%dir %{_datadir}/ngspice
%if 0%{?with_oldapps}
%{_bindir}/ngmakeidx
%{_bindir}/ngmultidec
%{_bindir}/ngnutmeg
%{_bindir}/ngproc2mod
%{_bindir}/ngsconvert
%{_mandir}/man1/ngmultidec.1%{?ext_man}
%{_mandir}/man1/ngnutmeg.1%{?ext_man}
%{_mandir}/man1/ngsconvert.1%{?ext_man}
%{_mandir}/man1/ngmakeidx.1%{?ext_man}
%{_mandir}/man1/ngproc2mod.1%{?ext_man}
%{_datadir}/ngspice/helpdir
%endif

%files scripts
%{_datadir}/ngspice/scripts

%files doc
%doc ngspice-%{version}-manual.pdf

%files xspice-cm
%{_bindir}/cmpp
%{_mandir}/man1/cmpp.1%{?ext_man}
%{_libdir}/%{pname}

%files xspice-cm-devel
%doc Stuarts_Poly_Notes src/xspice/icm/README
%{_includedir}/%{pname}
%{_datadir}/%{pname}/dlmain.c

%else
%files -n lib%{pname}%{so_ver}
%{_libdir}/lib%{pname}.so.*

%files -n lib%{pname}-devel
%dir %{_includedir}/%{pname}
%{_includedir}/%{pname}/sharedspice.h
%{_libdir}/lib%{pname}.so
%{_libdir}/pkgconfig/%{pname}.pc
%endif

%changelog
* Sat Jan  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 30
  * Bug fixes: 15 bugs that users have reported on the ngspice bug
    tracker have been fixed. Other bugs and some memory leaks have
    been removed as well.
  * New features: The VDMOS model has been overhauled and updated.
    A new variable 'controlswait' allows shifting the command
    sequence in shared ngspice to after the simulation.
  * Documentation: The manual making procedure has been setup anew.
    A html manual may be generated in addition to the pdf version.
- Update to version 29
  * Bug fixes: Small bugs fixed, lots of memory leaks removed.
  * New features: Enhanced compatibility modes with PSPICE (.include
    files or the complete netlist), LTSPICE compatibility started,
    not yet complete. New 'sidiode' simple diode model, new command
    'setseed', new internal variables 'no_auto_gnd' and 'inputdir'.
    Environmental variable SOURCE_DATE_EPOCH is supported.
  * Documentation: Updated pdf manual and other documentation.
- Update to version 28
  * License: All licenses involved are DFSG compatible.
  * Bug fixes: Small bugs fixed, memory leaks removed, code
    reorganized to improve its readability and safety.
  * New features: new VDMOS power MOS model, ngspice reads device
    libs with PSPICE syntax, old apps like ngnutmeg are made only
    upon user reqest, new commands 'mc_source' and 'alterparam',
    instance parameters may be added to the .model line, new
    variable 'sim_status', ngspice shared library supports XSPICE
    digital event data over its interface, pkg-config added .
  * Documentation: Updated pdf manual and other documentation.
- set -fPIE/-pie also on Leap 42.x/SLE12, use LDFLAGS for -pie
* Sun May  6 2018 stefan.bruens@rwth-aachen.de
- Removed shared library header from non-shared devel package
* Tue Dec  5 2017 eich@suse.com
- Build shared library version of ngspice using the multibuild
  feature.
  Building the shared library version of ngspice requires a separate
  build which doesn't build the binaries and doesn't allow to build
  with the X Window System UI.
  Also it requires the package to be split in several sub-packages:
  * a package containing most of the ngspice binaries.
  * a package containing the shared library and a development
    package for applications using the ngspice API.
  * a code model package for Xspice and a development package
    for code models.
  * a scripts package
- Added -fpie and -pie to CFLAGS to ensure position independent
  executables.
* Tue Dec  5 2017 eich@suse.com
- Update to version 27
  * check for correct inductor coefficients
  * add variable 'win_console'
  * --enable-relpath configure flag to set preprocessor flag HAS_RELPATH
  * sets search path for spinit relativ to current directory
  * The search path for .spiceinit is: current dir, HOME dir, USERPROFILE dir
  * new function stddev to calculate the standard deviation of all elements
    of a vector
  * xspice digital n-input x m-output look-up table gate
  * xspice digital model d_lut (digital n-input look-up table gate)
  * add variable $sharedmode (if shared ngspice is running), to be used in
    scripts
  * enable msys2 for mingw compilation
  * OMP support for bsim3v3.24 model
  * bsim3v3.24: add model parameter lmlt (Channel length scaling)
  * OMP support for BSIM4.5 model
  * update and extension of command 'wrdata'
  * option xmu to set damping in trapezoid integration
  * command 'linearize' will take time data from transient analysis vector if
    no circuit is loaded
  * two new commands: edisplay and eprvcd
  * 'edisplay' will show a list of all event nodes
  * 'eprvcd' will print all event nodes in vcd format
  * XSPICE 2D and 3D table models
  * add variable 'batchmode' which is set when command line option `-b' is
    active
  * enable backquote substitution for Visual Studio console apps
  * update how-to-ngspice-vstudio.txt
  * update visualc directory and project files, add XSPICE code model
    generation by VS2015
  * allow access to 4 GB memory of 32 bit ngspice on 64 bit Windows, 8 TB for
    64 bit ngspice
  * new variable `interactive'
  * xspice, introduce cm_message_printf()
  * add variable `width' to command "print line ..."
  * support msys2
  * favor exponential temperatur equation if all parameters tc1, tc2 and tce
    are given for R
  * move libfftw3 sideways out of the ngspice tree
  * remove visual studio 2008 .vcproj files
  * visualc/sharedspice.vcxproj, updated and migrated with visual studio 2015
  * `E..table {expr} {pairs}', `G..', allow an optional `=' after `table'
  * `E..value=', `G..value=', allow `=' being optional
  * introduce TCE, exponential temperature coefficient for R
  * allow `temper' to be recognised when preceded by '='
  * allow cross-compilation, especially for MinGW-w64
  * allow "plot xlog ylog" (equiv to "plot loglog")
  * extend qa test to hisimhv version 2
  * update hisimhv model to version 2.2.0
  * update hisim model to version 2.8.0
  * .control variable "sqrnoise" to deliver noise data in squared
    representation
  * noise analysis, deliver results in V/sqrt(Hz) and A/sqrt(Hz)
  * add delvt0 for bsim4 models
  * bug fixes for diode model
  * allow a xspice circuit with exclusively xspice event nodes
  * man pages for cmpp ngmakeidx and ngproc2mod
  * implement `nint()'
  * everywhere: ln to the base e, log to the base e, log10 to the base 10
  * allow an optional '=' in ".func foo() = {expr}"
  * bsim4, update to version 4.8
  * update hisimhv to version 1.2.4
  * cmc quality check for bsim3 model
  * nested indexing for vectors
  * option savecurrents to save current through all devices
  * option interp to plot interpolated raw file data
  * MS VS 2010 project file added for compatibility
  * XSPICE: new callback function cm_get_path
- ngspice-fix-warning.patch: Removed - obsolete.
- ngspice-gnuplot-terminal.patch replaced by
  ngspice-Use-gnuplot-terminal-auto-detection.patch
* Sun Jun  4 2017 malcolmlewis@opensuse.org
- Revert previous changes as this builds a shared engine only not
  executable binaries.
- Clean up spec file, fix license naming and update copyright year.
- Add verbose building with V=1.
- Add -fPIC and -fopenmp flags to Tumbleweed builds.
* Sun Mar 26 2017 xxxxxmichl@googlemail.com
- enable shared lib build
- added sub package for shared lib and devel
* Tue Jun 10 2014 dmitry_r@opensuse.org
- Update to version 26
  * fft command may use fftw3 library
  * add nint() rounding function
  * usage of 'temper' in behavioral devices
  * check for soa (safe operating area) in several device models
  * library processing rewritten completely to enhance ngspice
    compatibility (.lib)
  * include file processing rewritten to allow nesting and various
    absolute and relative path names (.inc)
  * asinh, acosh, atanh functions
  * shared ngspice option added: ngspice optionally compiles as
    a shared object or dynamic link library
  * use a hash table to massively speed up parsing the netlist
  * implement a very basic .if/.else block
  * implement a signed power function `pwr' for controlled sources
  * implement multiplier `m' in F, G source
  * apply Area Calculation Method (ACM) to the bsim3v3.3 model
  * implement `tc1', `tc2' instance parameters
- Split documentation to separate package
- Build with cider and openmp support
- Don't set gnuplot terminal, use autodetection
  * ngspice-gnuplot-terminal.patch
* Sat Apr  6 2013 werner.ho@gmx.de
- new version ngspice 25
* Wed Aug 29 2012 scorot@free.fr
- fix build for i586
- spec file reformating
* Sun Feb  5 2012 werner.ho@gmx.de
- new version ngspice 24
* Mon Jun  6 2011 Werner Hoch <werner.ho@gmx.de>
- new version 23
* Thu Oct 14 2010 Werner Hoch <werner.ho@gmx.de>
- new version 22
* Mon Jun 21 2010 Werner Hoch <werner.ho@gmx.de>
- new version 21
- removed info pages, added pdf manual
* Sun Dec 20 2009 Werner Hoch <werner.ho@gmx.de>
- new version 20
* Sun Nov 15 2009 Werner Hoch <werner.ho@gmx.de>
- packaging fix
* Tue Dec 16 2008 Werner Hoch <werner.ho@gmx.de>
- new version 18
- removed build options for older distributions
* Mon Jun 18 2007 Werner Hoch <werner.ho@gmx.de>
- added setlibpath_spinit.in.patch for x86_64
  that fixes the load of xspice codemodels
* Tue Sep 12 2006 Werner Hoch <werner.ho@gmx.de>
- enabled xspice extentions
* Wed Aug 30 2006 Werner Hoch <werner.ho@gmx.de>
- added %%%%{FORTRAN_GCC} decision
* Sun Aug 27 2006 Werner Hoch <werner.ho@gmx.de>
- first spec file
